@@ -20,7 +20,6 @@ import six
 
 from openstack.cloud import exc
 from openstack.cloud import meta
-from openstack.cloud import openstackcloud
 from openstack.tests import fakes
 from openstack.tests.unit import base
 
@@ -409,10 +408,6 @@ class TestImage(BaseTestImage):
                      headers={'x-object-meta-x-sdk-md5': fakes.NO_MD5,
                               'x-object-meta-x-sdk-sha256': fakes.NO_SHA256})
                  ),
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'image', append=['images'], base_url_append='v2'),
-                 json={'images': []}),
             dict(method='POST',
                  uri=self.get_mock_url(
                      'image', append=['tasks'], base_url_append='v2'),
@@ -476,6 +471,14 @@ class TestImage(BaseTestImage):
                  uri='{endpoint}/{container}/{object}'.format(
                      endpoint=endpoint, container=self.container_name,
                      object=self.image_name)),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'image', append=['images'], base_url_append='v2'),
+                 json=self.fake_search_return),
+            # TODO(mordred) The task workflow results in an extra call
+            # in the upper level wait. We should be able to make this
+            # go away once we refactor a wait_for_image out in the next
+            # patch.
             dict(method='GET',
                  uri=self.get_mock_url(
                      'image', append=['images'], base_url_append='v2'),
@@ -553,7 +556,7 @@ class TestImage(BaseTestImage):
                      'Date': 'Thu, 16 Nov 2017 15:24:30 GMT',
                      'Accept-Ranges': 'bytes',
                      'Content-Type': 'application/octet-stream',
-                     openstackcloud.OBJECT_AUTOCREATE_KEY: 'true',
+                     self.cloud._OBJECT_AUTOCREATE_KEY: 'true',
                      'Etag': fakes.NO_MD5}),
             dict(method='DELETE',
                  uri='{endpoint}/{container}/{object}'.format(
